#
# Copyright (c) 2023, HILSTER - https://hilster.io
# All rights reserved.
#

import argparse
import platform
import sys
import webbrowser
from typing import Optional, List

import oser

if sys.argv[0].endswith("__main__.py"):  # pragma: no cover
    sys.argv[0] = "python -m oser"

if sys.argv[0].endswith("oser-script.py"):  # pragma: no cover
    sys.argv[0] = "oser"


def main(args: Optional[List[str]] = None) -> None:
    parser = argparse.ArgumentParser(description="oser (HILSTER - https://hilster.io)")

    subparsers = parser.add_subparsers(dest="command", help="the command")
    subparsers.required = True

    docs_parser = subparsers.add_parser("docs", help="open documents")  # noqa: F841

    license_parser = subparsers.add_parser("licenses", help="show open-source licenses")  # noqa: F841

    version_parser = subparsers.add_parser("version", help="show version")  # noqa: F841

    parsed_args = parser.parse_args(args=args)

    if parsed_args.command == "docs":
        url = "https://docs.hilster.io/oser/oser-{}/".format(oser.__version__)
        webbrowser.open(url)

    if parsed_args.command == "licenses":
        print(LICENSES)

    if parsed_args.command == "version":
        print(
            "oser-{oser_version} with Python {python_version} {machine}".format(
                oser_version=oser.__version__, python_version=platform.python_version(), machine=platform.machine()
            )
        )

    sys.exit(0)


LICENSES = """
Open Source Licenses
====================

The Sodium Crypto library (libsodium-1.0.10, http://libsodium.org)
------------------------------------------------------------------

Copyright (c) 2013-2016
Frank Denis <j at pureftpd dot org>

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
"""

if __name__ == "__main__":  # pragma: no cover
    main()
